# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apexnova/market/market_service.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'apexnova/market/market_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from apexnova.market import market_pb2 as apexnova_dot_market_dot_market__pb2
from apexnova.stub import authorization_context_pb2 as apexnova_dot_stub_dot_authorization__context__pb2
from apexnova.stub import response_pb2 as apexnova_dot_stub_dot_response__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$apexnova/market/market_service.proto\x12\x08\x61pexnova\x1a\x1c\x61pexnova/market/market.proto\x1a)apexnova/stub/authorization_context.proto\x1a\x1c\x61pexnova/stub/response.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"a\n\x10ReadStockRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12=\n\x15\x61uthorization_context\x18\x02 \x01(\x0b\x32\x1e.apexnova.AuthorizationContext\"j\n\x11ReadStockResponse\x12\x1e\n\x05stock\x18\x01 \x01(\x0b\x32\x0f.apexnova.Stock\x12\x35\n\x11standard_response\x18\x02 \x01(\x0b\x32\x1a.apexnova.StandardResponse\"\x91\x01\n\x10ReadQuoteRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12.\n\nquote_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x15\x61uthorization_context\x18\x03 \x01(\x0b\x32\x1e.apexnova.AuthorizationContext\"n\n\x11ReadQuoteResponse\x12\"\n\x05quote\x18\x01 \x01(\x0b\x32\x13.apexnova.QuoteInfo\x12\x35\n\x11standard_response\x18\x02 \x01(\x0b\x32\x1a.apexnova.StandardResponse\"\xdd\x01\n\x17StreamStatementsRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12)\n\x0b\x66iscal_year\x18\x02 \x01(\x0e\x32\x14.apexnova.FiscalYear\x12)\n\x06period\x18\x03 \x01(\x0e\x32\x19.apexnova.ReportingPeriod\x12\x0e\n\x06\x63ursor\x18\x04 \x01(\t\x12\r\n\x05limit\x18\x05 \x01(\x05\x12=\n\x15\x61uthorization_context\x18\x06 \x01(\x0b\x32\x1e.apexnova.AuthorizationContext\"\x8a\x01\n\x1d\x42\x61lanceSheetStatementResponse\x12\x32\n\tstatement\x18\x01 \x01(\x0b\x32\x1f.apexnova.BalanceSheetStatement\x12\x35\n\x11standard_response\x18\x02 \x01(\x0b\x32\x1a.apexnova.StandardResponse\"\x82\x01\n\x19\x43\x61shflowStatementResponse\x12.\n\tstatement\x18\x01 \x01(\x0b\x32\x1b.apexnova.CashflowStatement\x12\x35\n\x11standard_response\x18\x02 \x01(\x0b\x32\x1a.apexnova.StandardResponse\"~\n\x17IncomeStatementResponse\x12,\n\tstatement\x18\x01 \x01(\x0b\x32\x19.apexnova.IncomeStatement\x12\x35\n\x11standard_response\x18\x02 \x01(\x0b\x32\x1a.apexnova.StandardResponse\"y\n\x13RevenueGrowthFilter\x12$\n\x06period\x18\x01 \x01(\x0e\x32\x14.apexnova.YearPeriod\x12\x1d\n\x15min_growth_percentage\x18\x02 \x01(\x01\x12\x1d\n\x15max_growth_percentage\x18\x03 \x01(\x01\"\x94\x01\n\x18\x46reeCashFlowGrowthFilter\x12$\n\x06period\x18\x01 \x01(\x0e\x32\x14.apexnova.YearPeriod\x12\x1d\n\x15min_growth_percentage\x18\x02 \x01(\x01\x12\x1d\n\x15max_growth_percentage\x18\x03 \x01(\x01\x12\x14\n\x0csbc_adjusted\x18\x04 \x01(\x08\"A\n\x0fMarketCapFilter\x12\x16\n\x0emin_market_cap\x18\x01 \x01(\x01\x12\x16\n\x0emax_market_cap\x18\x02 \x01(\x01\"9\n\x0bTtmPeFilter\x12\x14\n\x0cmin_pe_ratio\x18\x01 \x01(\x01\x12\x14\n\x0cmax_pe_ratio\x18\x02 \x01(\x01\"z\n\x0cMoversFilter\x12(\n\x06period\x18\x01 \x01(\x0e\x32\x18.apexnova.MovementPeriod\x12\x1f\n\x17min_movement_percentage\x18\x02 \x01(\x01\x12\x1f\n\x17max_movement_percentage\x18\x03 \x01(\x01\"\xb3\x03\n\x14StockScreenerRequest\x12\x35\n\x0erevenue_growth\x18\x01 \x01(\x0b\x32\x1d.apexnova.RevenueGrowthFilter\x12\x36\n\nfcf_growth\x18\x02 \x01(\x0b\x32\".apexnova.FreeCashFlowGrowthFilter\x12-\n\nmarket_cap\x18\x03 \x01(\x0b\x32\x19.apexnova.MarketCapFilter\x12\"\n\x07\x63ountry\x18\x04 \x01(\x0e\x32\x11.apexnova.Country\x12%\n\x06ttm_pe\x18\x05 \x01(\x0b\x32\x15.apexnova.TtmPeFilter\x12)\n\x08\x65xchange\x18\x06 \x01(\x0e\x32\x17.apexnova.StockExchange\x12 \n\x06sector\x18\x07 \x01(\x0e\x32\x10.apexnova.Sector\x12&\n\x06movers\x18\x08 \x01(\x0b\x32\x16.apexnova.MoversFilter\x12=\n\x15\x61uthorization_context\x18\t \x01(\x0b\x32\x1e.apexnova.AuthorizationContext\"n\n\x15StockScreenerResponse\x12\x1e\n\x05stock\x18\x01 \x01(\x0b\x32\x0f.apexnova.Stock\x12\x35\n\x11standard_response\x18\x02 \x01(\x0b\x32\x1a.apexnova.StandardResponse*\x8e\x01\n\nYearPeriod\x12\x1b\n\x17YEAR_PERIOD_UNSPECIFIED\x10\x00\x12\x12\n\x0eYEAR_PERIOD_1Y\x10\x01\x12\x12\n\x0eYEAR_PERIOD_2Y\x10\x02\x12\x12\n\x0eYEAR_PERIOD_3Y\x10\x03\x12\x12\n\x0eYEAR_PERIOD_5Y\x10\x04\x12\x13\n\x0fYEAR_PERIOD_10Y\x10\x05*\xaa\x01\n\x0eMovementPeriod\x12\x1f\n\x1bMOVEMENT_PERIOD_UNSPECIFIED\x10\x00\x12\x16\n\x12MOVEMENT_PERIOD_1D\x10\x01\x12\x16\n\x12MOVEMENT_PERIOD_1W\x10\x02\x12\x16\n\x12MOVEMENT_PERIOD_1M\x10\x03\x12\x16\n\x12MOVEMENT_PERIOD_1Y\x10\x04\x12\x17\n\x13MOVEMENT_PERIOD_YTD\x10\x05\x32\xa4\x04\n\x0cStockService\x12\x44\n\tReadStock\x12\x1a.apexnova.ReadStockRequest\x1a\x1b.apexnova.ReadStockResponse\x12\x44\n\tReadQuote\x12\x1a.apexnova.ReadQuoteRequest\x1a\x1b.apexnova.ReadQuoteResponse\x12l\n\x1cStreamBalanceSheetStatements\x12!.apexnova.StreamStatementsRequest\x1a\'.apexnova.BalanceSheetStatementResponse0\x01\x12\x64\n\x18StreamCashflowStatements\x12!.apexnova.StreamStatementsRequest\x1a#.apexnova.CashflowStatementResponse0\x01\x12`\n\x16StreamIncomeStatements\x12!.apexnova.StreamStatementsRequest\x1a!.apexnova.IncomeStatementResponse0\x01\x12R\n\rStockScreener\x12\x1e.apexnova.StockScreenerRequest\x1a\x1f.apexnova.StockScreenerResponse0\x01\x42*\n\x13\x63om.apexnova.marketB\x11StockServiceProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apexnova.market.market_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.apexnova.marketB\021StockServiceProtoP\001'
  _globals['_YEARPERIOD']._serialized_start=2354
  _globals['_YEARPERIOD']._serialized_end=2496
  _globals['_MOVEMENTPERIOD']._serialized_start=2499
  _globals['_MOVEMENTPERIOD']._serialized_end=2669
  _globals['_READSTOCKREQUEST']._serialized_start=186
  _globals['_READSTOCKREQUEST']._serialized_end=283
  _globals['_READSTOCKRESPONSE']._serialized_start=285
  _globals['_READSTOCKRESPONSE']._serialized_end=391
  _globals['_READQUOTEREQUEST']._serialized_start=394
  _globals['_READQUOTEREQUEST']._serialized_end=539
  _globals['_READQUOTERESPONSE']._serialized_start=541
  _globals['_READQUOTERESPONSE']._serialized_end=651
  _globals['_STREAMSTATEMENTSREQUEST']._serialized_start=654
  _globals['_STREAMSTATEMENTSREQUEST']._serialized_end=875
  _globals['_BALANCESHEETSTATEMENTRESPONSE']._serialized_start=878
  _globals['_BALANCESHEETSTATEMENTRESPONSE']._serialized_end=1016
  _globals['_CASHFLOWSTATEMENTRESPONSE']._serialized_start=1019
  _globals['_CASHFLOWSTATEMENTRESPONSE']._serialized_end=1149
  _globals['_INCOMESTATEMENTRESPONSE']._serialized_start=1151
  _globals['_INCOMESTATEMENTRESPONSE']._serialized_end=1277
  _globals['_REVENUEGROWTHFILTER']._serialized_start=1279
  _globals['_REVENUEGROWTHFILTER']._serialized_end=1400
  _globals['_FREECASHFLOWGROWTHFILTER']._serialized_start=1403
  _globals['_FREECASHFLOWGROWTHFILTER']._serialized_end=1551
  _globals['_MARKETCAPFILTER']._serialized_start=1553
  _globals['_MARKETCAPFILTER']._serialized_end=1618
  _globals['_TTMPEFILTER']._serialized_start=1620
  _globals['_TTMPEFILTER']._serialized_end=1677
  _globals['_MOVERSFILTER']._serialized_start=1679
  _globals['_MOVERSFILTER']._serialized_end=1801
  _globals['_STOCKSCREENERREQUEST']._serialized_start=1804
  _globals['_STOCKSCREENERREQUEST']._serialized_end=2239
  _globals['_STOCKSCREENERRESPONSE']._serialized_start=2241
  _globals['_STOCKSCREENERRESPONSE']._serialized_end=2351
  _globals['_STOCKSERVICE']._serialized_start=2672
  _globals['_STOCKSERVICE']._serialized_end=3220
# @@protoc_insertion_point(module_scope)
